#
# spec file for package python-time-machine
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-time-machine
Group:          Development/Languages/Python
Version:        2.9.0
Release:        3.2
Summary:        Travel through time in your tests
License:        MIT
URL:            https://github.com/adamchainz/time-machine
# pypi packages don't contain the tests anymore since 2.2.0, see changelog
Source:         https://github.com/adamchainz/time-machine/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION tests
BuildRequires:  %{python_module backports.zoneinfo if %python-base < 3.9}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  timezone
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
Requires:       python-python-dateutil
Requires:       timezone
%python_subpackages

%description
This library mocks all functions from Python's standard library that return the current date or datetime.
It can be used independently, as a function decorator, or as a context manager.

%prep
%setup -q -n time-machine-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest_arch

%files %{python_files}
%doc README.rst HISTORY.rst
%license LICENSE
%{python_sitearch}/time_machine
%{python_sitearch}/_time_machine.*.so
%{python_sitearch}/time_machine-%{version}.dist-info

%changelog
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed May 31 2023 Ben Greiner <code@bnavigator.de>
- Move to PEP517
- Do not use pytzdata, but system timezone directly
- Don't catchall sitearch
* Sat May 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.9.0:
  * Explicitly error when attempting to install on PyPy.
* Tue Apr 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire python38-backports.zoneinfo only when python38-base
  is present in the buildsystem: fix build on distros where python
  3.8 is no longer in the supported set of python interpreters.
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.8.2
  * Improve type hints for time_machine.travel() to preserve the types of the wrapped function/coroutine/class.
* Thu Aug 18 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.8.1:
  - Actually build Python 3.11 wheels.
- update to version 2.8.0:
  - Build Python 3.11 wheels.
- update to version 2.7.1:
  - Fix usage of ``ZoneInfo`` from the ``backports.zoneinfo`` package.
  This makes ``ZoneInfo`` support work for Python < 3.9.
- update to version 2.7.0:
  - Support Python 3.11 (no wheels yet, they will only be available when Python 3.11 is RC when the ABI is stable).
* Tue Jan 11 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Limit package to python >= 3.7
* Mon Jan 10 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.6.0:
  * Drop Python 3.6 support.
* Tue Dec 14 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.5.0:
  * Add ``time_machine.escape_hatch``, which provides functions to bypass
    time-machine.
    Thanks to Matt Pegler for the feature request in `Issue #206
    <https://github.com/adamchainz/time-machine/issues/206>`__.
* Tue Dec 14 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Sat Nov 27 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.1:
  - Build musllinux wheels.
* Sat Sep  4 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.4.0:
  - Support Python 3.10.
* Fri Jul 30 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.3.1:
  - Build universal2 wheels for Python 3.8 on macOS.
- update to version 2.3.0:
  - Allow passing ``tick`` to ``Coordinates.move_to()`` and the pytest fixture’s
  ``time_machine.move_to()``. This allows freezing or unfreezing of time when
  travelling.
* Sat Jul  3 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.2.0:
  - Include type hints.
  - Convert C module to use PEP 489 multi-phase extension module initialization.
  This makes the module ready for Python sub-interpreters.
  - Release now includes a universal2 wheel for Python 3.9 on macOS, to work on
  Apple Silicon.
  - Stop distributing tests to reduce package size. Tests are not intended to be
  run outside of the tox setup in the repository. Repackagers can use GitHub's
  tarballs per tag.
* Sat May 29 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- skip python2 to fix leap build
- add missing group tag to fix leap build
* Tue May 25 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 2.1.0.
